# Orbizen Cloud Deployment API Changes

This document summarizes the changes made to fix the deployment API endpoint for the Orbizen Cloud CLI project.

## Server-Side Changes

### 1. Created New API Endpoints

- **`auth/deploy.php`**: Handles deployments for the new subdomain-based URL structure (`projects/{project_id}/deploy`)
- **`auth/project_deploy.php`**: Handles deployments for the legacy path-based URL structure (`cli/project/{project_id}/deploy`)

### 2. Added API Routing

- **`auth/.htaccess`**: Created an .htaccess file to route API requests to the correct PHP files:
  - `/api/v1/projects/{project_id}/deploy` → `deploy.php`
  - `/api/v1/cli/project/{project_id}/deploy` → `project_deploy.php`

### 3. Database Support

- **`auth/deployments.sql`**: Added SQL to create a `deployments` table for tracking project deployments

### 4. Documentation

- **`auth/README.md`**: Added documentation for setting up and using the deployment API
- **`auth/test_deploy.php`**: Created a test script to verify the deployment API functionality

## Client-Side Changes

### 1. Updated Deployment Logic

- **`orbizen/utils/project.py`**: Modified the `deploy_project()` function to use the correct API endpoint based on the domain format:
  - For subdomain-based URLs (`{project_id}.orbizen.cloud`): Uses `/api/v1/projects/{project_id}/deploy`
  - For path-based URLs: Uses `/api/v1/cli/project/{project_id}/deploy`

### 2. Updated Project Creation

- **`orbizen/utils/project.py`**: Updated the `create_project()` function to use the new subdomain format:
  - Changed domain from `orbizen.cloud/cli/project/{project_id}` to `{project_id}.orbizen.cloud`
  - Changed phpMyAdmin URL from `orbizen.cloud/cli/project/{project_id}/phpmyadmin` to `{project_id}.orbizen.cloud/phpmyadmin`

## Implementation Details

### Deployment Process

1. The client creates a ZIP file of the project files
2. The client uploads the ZIP file to the appropriate API endpoint
3. The server extracts the ZIP file to a temporary directory
4. The server copies the files to the project's public_html directory
5. The server records the deployment in the database
6. The server returns a success response with the project details

### Authentication

- Both API endpoints use JWT token authentication
- The token is sent in the Authorization header (`Bearer {token}`)
- For testing purposes, a user_id parameter can be provided in the URL

### Error Handling

- The API returns appropriate HTTP status codes for different error conditions
- Detailed error messages are provided in the response JSON
- All file operations are wrapped in try-catch blocks to handle exceptions

## Testing

Use the `auth/test_deploy.php` script to test the deployment API:

1. Configure the test parameters (project_id, API token)
2. Create or upload a test ZIP file
3. Submit the form to test the API
4. View the API response and error messages if any 