# Orbizen Cloud CLI

A command-line interface tool for Orbizen Cloud that allows users to deploy web projects, manage websites, handle databases, and update applications using a git-like workflow.

## Installation

### macOS
```bash
brew install orbizen-cli
```

### Linux
```bash
curl -fsSL https://orbizen.cloud/install.sh | sh
```

### Windows
Download the installer executable from [Orbizen Cloud](https://orbizen.cloud/downloads/orbizen-cli.exe)

## Basic Usage

```bash
# Display help information, system statistics, and version details
orbizen --help     # Show detailed command help and usage
orbizen --stats    # Display system statistics and resource usage
orbizen --info     # Show detailed version and environment information
orbizen            # Show quick reference help (same as --help)

# Display version
orbizen -v

# Authentication
orbizen login
orbizen register
```

## Project Management

```bash
# Initialize a new project
orbizen init                  # Creates a new project directory with necessary configuration files
                            # and initializes version control for your project

# Stage files for deployment (similar to git add)
orbizen add <filename>       # Stage a specific file for deployment
                            # Example: orbizen add index.html
orbizen add .               # Stage all files in current directory for deployment
                            # This includes all files and subdirectories

# Create versioned snapshots (similar to git commit)
orbizen commit "message"     # Creates a new version snapshot with your staged changes
                            # The message should describe what changes you made
                            # Example: orbizen commit "Added new homepage design"

# Deploy to Orbizen Cloud
orbizen remote cloud        # Connect your project to Orbizen Cloud
                            # This sets up the remote deployment target

orbizen remote -V [private|group|public]  # Set project visibility level
                            # private: Only accessible from allowed IPs
                            # group: Accessible from specific IP ranges
                            # public: Accessible from anywhere

orbizen remote -u deploy    # Deploy your committed changes to Orbizen Cloud
                            # This uploads your latest version to the server.

# List and select projects
orbizen list project
orbizen select -p <project-name>

# Server-side terminal
orbizen open cli
orbizen close terminal

# Delete project
orbizen delete -p <project-id>
```

## Project Updates & Synchronization

```bash
# Update workflow
orbizen commit 'update message'
orbizen remote -u deploy

# Synchronization
orbizen pull -u list
orbizen pull
orbizen -p merge

# Merge with the currently selected project (from the project directory)
orbizen merge

# Merge with a specific project ID
orbizen merge project-id-xyz

# Merge and prefer cloud version in case of conflicts
orbizen merge --prefer cloud

# See what would be merged without making changes
orbizen merge --dry-run

# Merge with specific project and options combined
orbizen merge project-id-xyz --prefer cloud --dry-run
```

## Additional Features

```bash
orbizen clone --enable/--disable
orbizen clone <project-subdomain>
orbizen feedback
orbizen donate --amount <value>
orbizen status
```

## License

© 2025 Orbizen Cloud. All Rights Reserved. 