# Project Visibility Feature

This feature allows Orbizen Cloud project owners to control the visibility of their projects.

## Available Visibility Settings

- **Private**: Only the project owner can access the project
- **Group**: Only specified IP addresses can access the project
- **Public**: Anyone can access the project

## Server-Side Changes

1. **Added visibility column to projects table**:
   - Added a visibility ENUM ('private', 'group', 'public') column with a default value of 'private'
   - Added an index for faster queries

2. **Updated the projects.php API endpoint**:
   - Added PUT method support for updating project visibility
   - Added proper validation for visibility values

3. **Updated .htaccess rules**:
   - Added routing for visibility endpoint at `/api/projects/{project_id}/visibility`

## Client-Side Changes

1. **Updated the remote command**:
   - Added a -V/--visibility option to the remote command for direct access
   - Created a visibility subcommand for detailed configuration

2. **Updated project display**:
   - Added visibility column to project listing
   - Updated project details to show visibility

## How to Use

### Set Project Visibility

```bash
# Set project visibility directly with the remote command
orbizen remote -V private
orbizen remote -V group     # Will prompt for allowed IP addresses
orbizen remote -V public

# Or use the visibility subcommand
orbizen remote visibility -V private
orbizen remote visibility -V group
orbizen remote visibility -V public
```

### View Project Visibility

```bash
# List all projects with visibility info
orbizen list-project

# View detailed project info including visibility
orbizen select -p project-name
```

## Implementation Notes

- The visibility settings are stored both on the server and in the local configuration
- For 'group' visibility, the allowed IP addresses are stored in the configuration
- The server enforces visibility settings when accessing the project
- The default visibility is 'private' for all new projects 