# Orbizen Cloud CLI installer script for Windows
# Must be run with administrator privileges

# Check if Python is installed
try {
    $pythonVersion = (python --version 2>&1)
    if ($pythonVersion -match 'Python (\d+\.\d+\.\d+)') {
        $version = $matches[1]
        $majorMinor = $version -replace '^(\d+\.\d+).*', '$1'
        if ([double]$majorMinor -lt 3.8) {
            Write-Host "Error: Python 3.8 or later is required." -ForegroundColor Red
            Write-Host "Current version: $version"
            Write-Host "Please upgrade your Python installation and try again."
            exit 1
        }
    } else {
        throw "Python not found"
    }
} catch {
    Write-Host "Error: Python is required but not installed." -ForegroundColor Red
    Write-Host "Please install Python 3.8 or later from https://www.python.org/downloads/"
    Write-Host "Be sure to check 'Add Python to PATH' during installation."
    exit 1
}

# Check if pip is installed
try {
    pip --version | Out-Null
} catch {
    Write-Host "Warning: pip is not installed or not in PATH." -ForegroundColor Yellow
    Write-Host "Attempting to install pip..."
    python -m ensurepip --upgrade
    if ($LASTEXITCODE -ne 0) {
        Write-Host "Error: Unable to install pip automatically." -ForegroundColor Red
        Write-Host "Please install pip manually and try again."
        exit 1
    }
}

# Install or upgrade Orbizen CLI
Write-Host "Installing Orbizen Cloud CLI..." -ForegroundColor Cyan
pip install --upgrade orbizen-cli

# Verify installation
try {
    $orbizenVersion = (orbizen -v 2>&1)
    Write-Host "Orbizen Cloud CLI $orbizenVersion installed successfully!" -ForegroundColor Green
    Write-Host "Run 'orbizen' to get started."
} catch {
    Write-Host "Installation failed." -ForegroundColor Red
    Write-Host "Please try installing manually with: pip install orbizen-cli"
    exit 1
} 