"""
Delete command for Orbizen CLI.
"""
import os
import click
from colorama import Fore, Style

from orbizen.utils.project import get_remote_config
from orbizen.utils.api import delete_project, APIError
from orbizen.utils.config import is_orbizen_project

@click.command()
@click.argument('project-id', required=True)
def delete(project_id):
    """Delete a project from Orbizen Cloud."""
    if is_orbizen_project():
        # Check if this is the current project
        remote_config = get_remote_config()
        if remote_config and remote_config.get('id') == project_id:
            if not click.confirm(f"You are about to delete the current project ({project_id}). This cannot be undone. Continue?"):
                click.echo("Aborting.")
                return
        else:
            if not click.confirm(f"Are you sure you want to delete project {project_id}? This cannot be undone."):
                click.echo("Aborting.")
                return
    else:
        if not click.confirm(f"Are you sure you want to delete project {project_id}? This cannot be undone."):
            click.echo("Aborting.")
            return
    
    try:
        # Try to delete the project
        response = delete_project(project_id)
        
        # Check if deletion was successful
        if response and response.get('status') == 'success':
            click.echo(f"{Fore.GREEN}Project {project_id} deleted successfully.{Style.RESET_ALL}")
            
            # If the project has files_deleted status
            if 'data' in response and 'files_deleted' in response['data']:
                if response['data']['files_deleted']:
                    click.echo(f"{Fore.GREEN}Project files were removed from the server.{Style.RESET_ALL}")
                else:
                    click.echo(f"{Fore.YELLOW}Project was removed from the database, but files could not be deleted.{Style.RESET_ALL}")
                    if 'error' in response['data']:
                        click.echo(f"{Fore.YELLOW}Error: {response['data']['error']}{Style.RESET_ALL}")
        else:
            error_msg = response.get('message', 'Unknown error') if response else 'No response'
            click.echo(f"{Fore.RED}Failed to delete project: {error_msg}{Style.RESET_ALL}")
    except APIError as e:
        click.echo(f"{Fore.RED}Error deleting project: {str(e)}{Style.RESET_ALL}") 